```
Usage: vcd network routed update-ip-range [OPTIONS] <name>

Options:
  -i, --ip-range <ip>      ip range in StartAddress-EndAddress format
                           [required]
  -n, --new-ip-range <ip>  ip range in StartAddress-EndAddress format
                           [required]
  -h, --help               Show this message and exit.

```
